@@ -14,20 +14,20 @@
 # under the License.
 
 import ipaddress
-import logging
 import os
 import socket
 import stat
 import subprocess
 
 import jinja2
-import netifaces
 from oslo_config import cfg
+from oslo_log import log as logging
 import pyroute2
 import six
 import webob
 from werkzeug import exceptions
 
+import netifaces
 from octavia.common import constants as consts
 
 
@@ -60,7 +60,7 @@ class Plug(object):
                 else six.u(subnet_cidr))
             vip = ip.exploded
             broadcast = network.broadcast_address.exploded
-            netmask = (network.prefixlen if ip.version is 6
+            netmask = (network.prefixlen if ip.version == 6
                        else network.netmask.exploded)
             vrrp_version = None
             if vrrp_ip:
@@ -127,10 +127,26 @@ class Plug(object):
         sysctl = pyroute2.NSPopen(consts.AMPHORA_NAMESPACE,
                                   [consts.SYSCTL_CMD, '--system'],
                                   stdout=subprocess.PIPE)
+
         sysctl.communicate()
         sysctl.wait()
         sysctl.release()
 
+        cmd_list = [['modprobe', 'ip_vs'],
+                    [consts.SYSCTL_CMD, '-w', 'net.ipv4.vs.conntrack=1']]
+        if ip.version == 4:
+            # For lvs function, enable ip_vs kernel module, enable ip_forward
+            # conntrack in amphora network namespace.
+            cmd_list.append([consts.SYSCTL_CMD, '-w', 'net.ipv4.ip_forward=1'])
+        elif ip.version == 6:
+            cmd_list.append([consts.SYSCTL_CMD, '-w',
+                             'net.ipv6.conf.all.forwarding=1'])
+        for cmd in cmd_list:
+            ns_exec = pyroute2.NSPopen(consts.AMPHORA_NAMESPACE, cmd,
+                                       stdout=subprocess.PIPE)
+            ns_exec.wait()
+            ns_exec.release()
+
         with pyroute2.IPRoute() as ipr:
             # Move the interfaces into the namespace
             idx = ipr.link_lookup(ifname=default_netns_interface)[0]
