@@ -12,11 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-
 from oslo_config import cfg
+from oslo_log import log as logging
 from pecan import rest
-from stevedore import driver as stevedore_driver
+from wsme import types as wtypes
 
 from octavia.common import constants
 from octavia.common import data_models
@@ -34,11 +33,6 @@ class BaseController(rest.RestController):
     def __init__(self):
         super(BaseController, self).__init__()
         self.repositories = repositories.Repositories()
-        self.handler = stevedore_driver.DriverManager(
-            namespace='octavia.api.handlers',
-            name=CONF.api_settings.api_handler,
-            invoke_on_load=True
-        ).driver
 
     @staticmethod
     def _convert_db_to_type(db_entity, to_type, children=False):
@@ -59,61 +53,89 @@ class BaseController(rest.RestController):
         return converted
 
     @staticmethod
-    def _get_db_obj(session, repo, data_model, id):
+    def _get_db_obj(session, repo, data_model, id, show_deleted=True):
         """Gets an object from the database and returns it."""
-        db_obj = repo.get(session, id=id)
+        db_obj = repo.get(session, id=id, show_deleted=show_deleted)
         if not db_obj:
-            LOG.exception('%(name)s %(id)s not found',
-                          {'name': data_model._name(), 'id': id})
+            LOG.debug('%(name)s %(id)s not found',
+                      {'name': data_model._name(), 'id': id})
             raise exceptions.NotFound(
                 resource=data_model._name(), id=id)
         return db_obj
 
-    def _get_db_lb(self, session, id):
+    def _get_db_lb(self, session, id, show_deleted=True):
         """Get a load balancer from the database."""
         return self._get_db_obj(session, self.repositories.load_balancer,
-                                data_models.LoadBalancer, id)
+                                data_models.LoadBalancer, id,
+                                show_deleted=show_deleted)
 
-    def _get_db_listener(self, session, id):
+    def _get_db_listener(self, session, id, show_deleted=True):
         """Get a listener from the database."""
         return self._get_db_obj(session, self.repositories.listener,
-                                data_models.Listener, id)
+                                data_models.Listener, id,
+                                show_deleted=show_deleted)
 
-    def _get_db_pool(self, session, id):
+    def _get_listener_and_loadbalancer_id(self, db_l7policy):
+        """Get listener and loadbalancer ids from the l7policy db_model."""
+        load_balancer_id = db_l7policy.listener.load_balancer_id
+        listener_id = db_l7policy.listener_id
+        return load_balancer_id, listener_id
+
+    def _get_db_pool(self, session, id, show_deleted=True):
         """Get a pool from the database."""
         return self._get_db_obj(session, self.repositories.pool,
-                                data_models.Pool, id)
+                                data_models.Pool, id,
+                                show_deleted=show_deleted)
 
-    def _get_db_member(self, session, id):
+    def _get_db_member(self, session, id, show_deleted=True):
         """Get a member from the database."""
         return self._get_db_obj(session, self.repositories.member,
-                                data_models.Member, id)
+                                data_models.Member, id,
+                                show_deleted=show_deleted)
 
-    def _get_db_l7policy(self, session, id):
+    def _get_db_hm(self, session, id, show_deleted=True):
+        """Get a health monitor from the database."""
+        return self._get_db_obj(session, self.repositories.health_monitor,
+                                data_models.HealthMonitor, id,
+                                show_deleted=show_deleted)
+
+    def _get_db_l7policy(self, session, id, show_deleted=True):
         """Get a L7 Policy from the database."""
         return self._get_db_obj(session, self.repositories.l7policy,
-                                data_models.L7Policy, id)
+                                data_models.L7Policy, id,
+                                show_deleted=show_deleted)
 
-    def _get_db_l7rule(self, session, id):
+    def _get_db_l7rule(self, session, id, show_deleted=True):
         """Get a L7 Rule from the database."""
         return self._get_db_obj(session, self.repositories.l7rule,
-                                data_models.L7Rule, id)
+                                data_models.L7Rule, id,
+                                show_deleted=show_deleted)
 
-    def _get_db_amp(self, session, id):
+    def _get_db_amp(self, session, id, show_deleted=True):
         """Gets an Amphora from the database."""
         return self._get_db_obj(session, self.repositories.amphora,
-                                data_models.Amphora, id)
+                                data_models.Amphora, id,
+                                show_deleted=show_deleted)
 
-    def _get_lb_project_id(self, session, id):
+    def _get_lb_project_id(self, session, id, show_deleted=True):
         """Get the project_id of the load balancer from the database."""
         lb = self._get_db_obj(session, self.repositories.load_balancer,
-                              data_models.LoadBalancer, id)
+                              data_models.LoadBalancer, id,
+                              show_deleted=show_deleted)
         return lb.project_id
 
-    def _get_l7policy_project_id(self, session, id):
+    def _get_lb_project_id_provider(self, session, id, show_deleted=True):
+        """Get the project_id of the load balancer from the database."""
+        lb = self._get_db_obj(session, self.repositories.load_balancer,
+                              data_models.LoadBalancer, id,
+                              show_deleted=show_deleted)
+        return lb.project_id, lb.provider
+
+    def _get_l7policy_project_id(self, session, id, show_deleted=True):
         """Get the project_id of the load balancer from the database."""
         l7policy = self._get_db_obj(session, self.repositories.l7policy,
-                                    data_models.LoadBalancer, id)
+                                    data_models.LoadBalancer, id,
+                                    show_deleted=show_deleted)
         return l7policy.project_id
 
     def _get_default_quotas(self, project_id):
@@ -188,7 +210,7 @@ class BaseController(rest.RestController):
                 members = self._get_attrs(obj)
                 for member in members:
                     if member not in fields:
-                        delattr(object_list[index], member)
+                        setattr(obj, member, wtypes.Unset)
         return object_list
 
     @staticmethod
