@@ -12,7 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import ipaddress
 import os
 import shutil
 
@@ -23,8 +22,6 @@ from octavia.amphorae.backends.agent.api_server import osutils
 from octavia.common import config
 from octavia.common import constants as consts
 from octavia.common import exceptions as octavia_exceptions
-from octavia.common import utils
-from octavia.tests.common import utils as test_utils
 from octavia.tests.unit import base
 
 
@@ -35,33 +32,37 @@ class TestOSUtils(base.TestCase):
 
         self.base_os_util = osutils.BaseOS('unknown')
 
-        with mock.patch('platform.linux_distribution',
-                        return_value=['Ubuntu', 'Foo', 'Bar']):
+        with mock.patch('distro.id',
+                        return_value='ubuntu'):
             self.ubuntu_os_util = osutils.BaseOS.get_os_util()
 
-        with mock.patch('platform.linux_distribution',
-                        return_value=['centos', 'Foo', 'Bar']):
+        with mock.patch('distro.id',
+                        return_value='rhel'):
             self.rh_os_util = osutils.BaseOS.get_os_util()
 
+        with mock.patch('distro.id',
+                        return_value='centos'):
+            self.centos_os_util = osutils.BaseOS.get_os_util()
+
     def test_get_os_util(self):
-        with mock.patch('platform.linux_distribution',
-                        return_value=['Ubuntu', 'Foo', 'Bar']):
+        with mock.patch('distro.id',
+                        return_value='ubuntu'):
             returned_cls = osutils.BaseOS.get_os_util()
             self.assertIsInstance(returned_cls, osutils.Ubuntu)
-        with mock.patch('platform.linux_distribution',
-                        return_value=['fedora', 'Foo', 'Bar']):
+        with mock.patch('distro.id',
+                        return_value='fedora'):
             returned_cls = osutils.BaseOS.get_os_util()
             self.assertIsInstance(returned_cls, osutils.RH)
-        with mock.patch('platform.linux_distribution',
-                        return_value=['redhat', 'Foo', 'Bar']):
+        with mock.patch('distro.id',
+                        return_value='rhel'):
             returned_cls = osutils.BaseOS.get_os_util()
             self.assertIsInstance(returned_cls, osutils.RH)
-        with mock.patch('platform.linux_distribution',
-                        return_value=['centos', 'Foo', 'Bar']):
+        with mock.patch('distro.id',
+                        return_value='centos'):
             returned_cls = osutils.BaseOS.get_os_util()
-            self.assertIsInstance(returned_cls, osutils.RH)
-        with mock.patch('platform.linux_distribution',
-                        return_value=['FakeOS', 'Foo', 'Bar']):
+            self.assertIsInstance(returned_cls, osutils.CentOS)
+        with mock.patch('distro.id',
+                        return_value='FakeOS'):
             self.assertRaises(
                 octavia_exceptions.InvalidAmphoraOperatingSystem,
                 osutils.BaseOS.get_os_util)
@@ -172,136 +173,20 @@ class TestOSUtils(base.TestCase):
                            cmd_get_version_of_installed_package(package_name))
         self.assertEqual(rh_cmd, returned_rh_cmd)
 
+    def test_cmd_get_version_of_installed_package_mapped(self):
+        package_name = 'haproxy'
+        centos_cmd = "rpm -q --queryformat %{VERSION} haproxy18"
+
+        returned_centos_cmd = (
+            self.centos_os_util.cmd_get_version_of_installed_package(
+                package_name))
+        self.assertEqual(centos_cmd, returned_centos_cmd)
+
     def test_has_ifup_all(self):
         self.assertTrue(self.base_os_util.has_ifup_all())
         self.assertTrue(self.ubuntu_os_util.has_ifup_all())
         self.assertFalse(self.rh_os_util.has_ifup_all())
 
-    def test_write_vip_interface_file(self):
-        netns_interface = u'eth1234'
-        FIXED_IP = u'192.0.2.2'
-        SUBNET_CIDR = u'192.0.2.0/24'
-        GATEWAY = u'192.51.100.1'
-        DEST1 = u'198.51.100.0/24'
-        DEST2 = u'203.0.113.0/24'
-        NEXTHOP = u'192.0.2.1'
-        MTU = 1450
-        FIXED_IP_IPV6 = u'2001:0db8:0000:0000:0000:0000:0000:0001'
-        # Subnet prefix is purposefully not 32, because that coincidentally
-        # matches the result of any arbitrary IPv4->prefixlen conversion
-        SUBNET_CIDR_IPV6 = u'2001:db8::/70'
-
-        ip = ipaddress.ip_address(FIXED_IP)
-        network = ipaddress.ip_network(SUBNET_CIDR)
-        broadcast = network.broadcast_address.exploded
-        netmask = network.netmask.exploded
-        netmask_prefix = utils.netmask_to_prefix(netmask)
-
-        ipv6 = ipaddress.ip_address(FIXED_IP_IPV6)
-        networkv6 = ipaddress.ip_network(SUBNET_CIDR_IPV6)
-        broadcastv6 = networkv6.broadcast_address.exploded
-        netmaskv6 = networkv6.prefixlen
-
-        host_routes = [
-            {'gw': NEXTHOP, 'network': ipaddress.ip_network(DEST1)},
-            {'gw': NEXTHOP, 'network': ipaddress.ip_network(DEST2)}
-        ]
-
-        path = self.ubuntu_os_util.get_network_interface_file(netns_interface)
-        mock_open = self.useFixture(test_utils.OpenFixture(path)).mock_open
-        mock_template = mock.MagicMock()
-
-        # Test an IPv4 VIP
-        with mock.patch('os.open'), mock.patch.object(
-                os, 'fdopen', mock_open):
-            self.ubuntu_os_util.write_vip_interface_file(
-                interface_file_path=path,
-                primary_interface=netns_interface,
-                vip=FIXED_IP,
-                ip=ip,
-                broadcast=broadcast,
-                netmask=netmask,
-                gateway=GATEWAY,
-                mtu=MTU,
-                vrrp_ip=None,
-                vrrp_version=None,
-                render_host_routes=host_routes,
-                template_vip=mock_template)
-
-        mock_template.render.assert_called_once_with(
-            consts=consts,
-            interface=netns_interface,
-            vip=FIXED_IP,
-            vip_ipv6=False,
-            prefix=netmask_prefix,
-            broadcast=broadcast,
-            netmask=netmask,
-            gateway=GATEWAY,
-            network=SUBNET_CIDR,
-            mtu=MTU,
-            vrrp_ip=None,
-            vrrp_ipv6=False,
-            host_routes=host_routes,
-            topology="SINGLE",
-        )
-
-        # Now test with an IPv6 VIP
-        mock_template.reset_mock()
-        with mock.patch('os.open'), mock.patch.object(
-                os, 'fdopen', mock_open):
-            self.ubuntu_os_util.write_vip_interface_file(
-                interface_file_path=path,
-                primary_interface=netns_interface,
-                vip=FIXED_IP_IPV6,
-                ip=ipv6,
-                broadcast=broadcastv6,
-                netmask=netmaskv6,
-                gateway=GATEWAY,
-                mtu=MTU,
-                vrrp_ip=None,
-                vrrp_version=None,
-                render_host_routes=host_routes,
-                template_vip=mock_template)
-
-        mock_template.render.assert_called_once_with(
-            consts=consts,
-            interface=netns_interface,
-            vip=FIXED_IP_IPV6,
-            vip_ipv6=True,
-            prefix=netmaskv6,
-            broadcast=broadcastv6,
-            netmask=netmaskv6,
-            gateway=GATEWAY,
-            network=SUBNET_CIDR_IPV6,
-            mtu=MTU,
-            vrrp_ip=None,
-            vrrp_ipv6=False,
-            host_routes=host_routes,
-            topology="SINGLE",
-        )
-
-    def test_write_port_interface_file(self):
-        netns_interface = 'eth1234'
-        MTU = 1450
-        fixed_ips = []
-        path = 'mypath'
-        mock_template = mock.MagicMock()
-        mock_open = self.useFixture(test_utils.OpenFixture(path)).mock_open
-        mock_gen_text = mock.MagicMock()
-
-        with mock.patch('os.open'), mock.patch.object(
-                os, 'fdopen', mock_open), mock.patch.object(
-                osutils.BaseOS, '_generate_network_file_text', mock_gen_text):
-            self.base_os_util.write_port_interface_file(
-                netns_interface=netns_interface,
-                fixed_ips=fixed_ips,
-                mtu=MTU,
-                interface_file_path=path,
-                template_port=mock_template)
-
-        mock_gen_text.assert_called_once_with(
-            netns_interface, fixed_ips, MTU, mock_template)
-
     @mock.patch('shutil.copy2')
     @mock.patch('os.makedirs')
     @mock.patch('shutil.copytree')
